var indexSectionsWithContent =
{
  0: "abcdefgilmnoprstuvw",
  1: "abdefimnoprstuvw",
  2: "acefimpstv",
  3: "acdegilprsu",
  4: "eft",
  5: "d",
  6: "clsu"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "files",
  3: "functions",
  4: "variables",
  5: "typedefs",
  6: "pages"
};

var indexSectionLabels =
{
  0: "All",
  1: "Classes",
  2: "Files",
  3: "Functions",
  4: "Variables",
  5: "Typedefs",
  6: "Pages"
};

